# 列表选择

> 以用户选择为例

1. 页面通过弹窗打开
2. 页面支持单选与多选
3. 页面关闭后返回选择结果

完整选择页面代码代码

```html
<!doctype html>
<html xmlns:th="http://www.thymeleaf.org">
<head>
    <base th:href="${#request.getContextPath() + '/'}">
    <meta charset="utf-8">
    <meta name="renderer" content="webkit">
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, minimum-scale=1.0, maximum-scale=1.0, user-scalable=0">
    <link rel="stylesheet" href="assets/fonts/font-awesome/css/font-awesome.css"/>
    <link rel="stylesheet" href="assets/js/vendor/viewer/viewer.min.css">
    <link rel="stylesheet" href="assets/layuiadmin/layui/css/layui.css" media="all">
    <link rel="stylesheet" href="assets/layuiadmin/style/admin.css" media="all">
</head>
<body>
<div class="layui-anim layui-anim-fadein">
    <div class="layui-row">
        <div class="layui-col-md12">
            <div class="layui-card">
                <div class="layui-card-body">
                    <div class="test-table-reload-btn" style="margin-bottom: 10px;">
                        <div class="layui-inline">
                            <input type="text" id="keywords" class="layui-input search-item" placeholder="输入用户名、昵称">
                        </div>
                        <button type="button" id="search" class="layui-btn layui-btn-sm">
                            <i class="fa fa-lg fa-search"></i> 搜索
                        </button>

                        <!-- 确定按钮 -->
                        <button type="button" class="layui-btn layui-btn-sm layui-btn-normal" id="confirm" style="float:right;">确定</button>
                        <!-- 确定按钮 -->
                    </div>
                    <table class="layui-hide" id="dataTable" lay-filter="dataTable"></table>
                </div>
            </div>
        </div>
    </div>
</div>
<script src="assets/layuiadmin/layui/layui.js"></script>
<script th:inline="javascript">
    layui.config({
        base: 'assets/layuiadmin/'
    }).extend({
        index: 'lib/index'
    }).use(['index', 'table', 'laydate', 'upload'], function() {
        var $ = layui.$;
        var $win = $(window);
        var table = layui.table;
        var admin = layui.admin;
        var layer = layui.layer;
        var laydate = layui.laydate;
        var selectType = top.restAjax.params(window.location.href).selectType;
        selectType = selectType ? selectType : 'radio';
        // 已经选择的列表
        var selectedIdArray = top.dialog.dialogData.selectedIdArray ? top.dialog.dialogData.selectedIdArray : [];
        // 将新的选择列表置空
        top.dialog.dialogData.newSelectedArray = null;
        // 正在选择
        var selectMap = {};
        var tableData = [];

        var tableUrl = 'api/teacher/listpage-user-unselected';

        // 初始化已选择的列表
        function initSelectMap() {
            for(var i = 0, item; item = selectedIdArray[i++];) {
                selectMap[item] = {
                    userId: item
                }
            }
        }
        initSelectMap();

        // 初始化表格
        function initTable() {
            // 设置选择类型
            $.extend(table, {config: {checkName: 'checked'}});
            table.render({
                elem: '#dataTable',
                id: 'dataTable',
                url: top.restAjax.path(tableUrl, []),
                width: admin.screen() > 1 ? '100%' : '',
                height: $win.height() - 60,
                limit: 20,
                limits: [20, 40, 60, 80, 100, 200],
                toolbar: '#headerToolBar',
                request: {
                    pageName: 'page',
                    limitName: 'rows'
                },
                cols: [
                    [
                        {type: selectType, fixed: 'left'},
                        {field:'rowNum', width:80, title: '序号', fixed: 'left', align:'center', templet: '<span>{{d.LAY_INDEX}}</span>'},
                        {field:'userUsername', width:140, title: '用户名', sort: true, align:'center',
                            templet: function(rowData) {
                                return '<a href="javascript:void(0);" lay-event="userUsernameEvent">'+ rowData.userUsername +'</a>';
                            }
                        },
                        {field:'userName', width:140, title: '昵称', sort: true, align:'center'},
                    ]
                ],
                page: true,
                parseData: function(data) {
                    // 默认勾选
                    for(var i = 0, item; item = data.rows[i++];) {
                        if(selectMap[item.userId]) {
                            item.checked = true;
                            // 重新赋值：在打开界面后直接确定关闭页面时回显正常
                            selectMap[item.userId] = item;
                        } else {
                            item.checked = false;
                        }
                    }
                    tableData = data.rows;
                    // 默认勾选

                    return {
                        'code': 0,
                        'msg': '',
                        'count': data.total,
                        'data': data.rows
                    };
                }
            });
        }
        // 重载表格
        function reloadTable(currentPage) {
            table.reload('dataTable', {
                url: top.restAjax.path(tableUrl, []),
                where: {
                    keywords: $('#keywords').val(),
                },
                page: {
                    curr: currentPage
                }
            });
        }
        initTable();

        // 关闭
        function close() {
            parent.layer.close(parent.layer.getFrameIndex(window.name));
        }

        /**
         * 清空选择
         */
        function clearSelect() {
            selectMap = {};
        }

        /**
         * 添加选择
         * @param item
         */
        function addSelect(item) {
            selectMap[item.userId] = item;
        }

        /**
         * 删除选择
         * @param item
         */
        function removeSelect(item) {
            delete selectMap[item.userId];
        }

        // 勾选事件
        table.on('checkbox(dataTable)', function(obj) {
            if(obj.type === 'all') {
                if(obj.checked) {
                    // 添加全部
                    for(var i = 0, item; item = tableData[i++];) {
                        addSelect(item);
                    }
                } else {
                    // 删除全部
                    for(var i = 0, item; item = tableData[i++];) {
                        removeSelect(item);
                    }
                }
            } else {
                if(obj.checked) {
                    addSelect(obj.data);
                } else {
                    removeSelect(obj.data);
                }
            }
        });

        // 勾选事件
        table.on('radio(dataTable)', function(obj) {
            clearSelect()
            addSelect(obj.data);
        });

        // 事件 - 确定
        $(document).on('click', '#confirm', function() {
            top.dialog.dialogData.newSelectedArray = [];
            for(var key in selectMap) {
                top.dialog.dialogData.newSelectedArray.push(selectMap[key]);
            }
            close();
        });

        // 事件 - 搜索
        $(document).on('click', '#search', function() {
            reloadTable(1);
        });
    });
</script>
</body>
</html>
```

打开页面

```javascript
// 已经选择的ID列表
top.dialog.dialogData.selectedIdArray = [$('#userId').val()];
top.dialog.open({
    // 打开页面，指定选择框类型
    url: 'route/teacher/list-user-unselected?selectType=radio',
    title: '选择用户',
    width: '1000px',
    height: '500px',
    onClose: function() {
        // 获取选择后的列表
        var newSelectedArray = top.dialog.dialogData.newSelectedArray;
        if(newSelectedArray && newSelectedArray.length != 0) {
            // 处理选择结果
            $('#userId').val(newSelectedArray[0].userId);
            $('#userName').val(newSelectedArray[0].userName);
        }
    }
});
```